<script>
    function initMap() {
        var location = {
            lat: {{ contact_information.latitude }},
            lng: {{ contact_information.longitude }}
        };
        var map = new google.maps.Map(document.getElementById('contact_map'), {
            zoom: 14,
            center: location
        });
        var marker = new google.maps.Marker({
            position: location,
            map: map
        });
    }
</script>
<script async defer src="https://maps.googleapis.com/maps/api/js?key={{ GMAPS_APIKEY }}&callback=initMap"></script>